# Examples In This Document

## Data files used in this documentation

Data files will be posted publicly once we finished the v1.0 development. Estimated time is May 2022.

## Download Analysis `.ipynb` files

The ALLCools documentation is organized by description pages (like the current page) and analysis pages 
(like [this page](../cell_level/basic/mch_mcg_100k_basic.ipynb)). For all the analysis pages, you can download the
executable `.ipynb` using the download button in the top right and use it as a template for your own data analysis.

```{figure} ./download_ipynb.png
---
height: 150px
name: download-ipynb-fig
---
Download the analysis page.
```
